### Open AI Server

If `oai_port` is specified in the configuration then a server will be started on that port. The server is compatable with the chat completions api for OpenAI.  

**Note:** Authorization header is not needed

**Endpoint:** `/v1/chat/completions`  
[See OpenAI official website for more information](https://platform.openai.com/docs/api-reference/chat/create)

